@@ -1,12 +1,13 @@
+import warnings
+
 import cv2
 import numpy as np
 import scipy.ndimage as ndi
-import warnings
+from astropy.modeling import fitting, models
 from dask import delayed
+from owl_dev.logging import logger
 from scipy.stats import median_abs_deviation
 from skimage.transform import rescale
-from astropy.modeling import models, fitting
-from owl_dev.logging import logger
 
 
 def get_stats(img, nsamples=1000):
@@ -52,7 +53,7 @@ def compute_mask(img, threshold, background=None):
 
     img = ndi.gaussian_filter(img, (3, 3))
 
-    mask = img > threshold  # z1 + threshold * z2
+    mask = img > 1.5 * threshold  # z1 + threshold * z2
 
     mask = ndi.binary_fill_holes(mask)
     mask = ndi.binary_opening(mask, iterations=10)
@@ -82,7 +83,7 @@ def detect_beads(  # noqa: C901
     min_area=3_000,
     max_area=50_000,
     threshold=6,
-    mad=0,
+    stats=None,
 ):
     """Detect beads in image using HoughCircles"""
     img = img.astype("float32")
@@ -92,7 +93,25 @@ def detect_beads(  # noqa: C901
     r_background = compute_background(r_img)
     background = rescale(r_background, 4)
 
-    mask = img - background > threshold * mad
+    mask = img > stats[0] + threshold * stats[1]
+    mask = ndi.binary_fill_holes(mask)
+
+    mask = (mask * 255).astype("uint8")
+    analysis = cv2.connectedComponentsWithStats(mask, 4, cv2.CV_16U)
+    (totalLabels, label_ids, values, centroid) = analysis
+
+    output = np.zeros(mask.shape, dtype="uint8")
+    for i in range(1, totalLabels):
+        area = values[i, cv2.CC_STAT_AREA]
+        if area < 50_000:
+            continue
+        componentMask = (label_ids == i).astype("uint8") * 255
+        # Creating the Final output mask
+        output = cv2.bitwise_or(output, componentMask)
+    mask_bg = output
+
+    mask = img - background > threshold * stats[1]
+    mask = np.maximum(mask * 255, mask_bg) > 0
     mask = ndi.binary_fill_holes(mask)
 
     mask = (
