@@ -26,7 +26,7 @@ class SettingsPlugin(WorkerPlugin):
 
 
 @pipeline
-def main(
+def main(  # noqa: C901
     *,
     input_path: Path,
     output_path: Path,
@@ -60,6 +60,11 @@ def main(
 
         input_path = output_path / "raw"
 
+        if overwrite:
+            if not (output_path / "OVERWRITE").exists():
+                logger.warn("Setting overwrite to false")
+                overwrite = False
+
         if "calibration" in recipes:
             logger.info("Running calibration recipe")
             from ..calibration import compute_calibrations
