@@ -2,7 +2,14 @@ from pathlib import Path
 
 import voluptuous as vo
 
-DEFAULT_RECIPES = ["raw2zarr", "calibration", "mosaic", "mosaic_preview", "bead_detect", "bead_detect2"]
+DEFAULT_RECIPES = [
+    "raw2zarr",
+    "calibration",
+    "mosaic",
+    "mosaic_preview",
+    "bead_detect",
+    "bead_detect_alt",
+]
 STITCHER_NAMES = ["stpt", "axio"]
 
 
