@@ -2,7 +2,7 @@ import itertools
 
 import numpy as np
 
-from .mutual_information import mutual_information
+from . import metrics
 
 
 def multi_peak_max(PCM):
@@ -87,7 +87,18 @@ def extract_overlap_subregion(image, y, x):
     return image[xstart:xend, ystart:yend]
 
 
-def interpret_translation(image1, image2, yins, xins, ymin, ymax, xmin, xmax, n=4):
+def interpret_translation(
+    image1,
+    image2,
+    yins,
+    xins,
+    ymin,
+    ymax,
+    xmin,
+    xmax,
+    n=4,
+    metric="structural_similarity",
+):
     """Interpret the translation to find the translation with heighest ncc.
 
     Parameters
@@ -159,7 +170,11 @@ def interpret_translation(image1, image2, yins, xins, ymin, ymax, xmin, xmax, n=
             if (ymin <= yval) and (yval <= ymax) and (xmin <= xval) and (xval <= xmax):
                 subI1 = extract_overlap_subregion(image1, yval, xval)
                 subI2 = extract_overlap_subregion(image2, -yval, -xval)
-                ncc_val = mutual_information(subI1, subI2)
+                metric_func = getattr(metrics, metric)
+                try:
+                    ncc_val = metric_func(subI1, subI2)
+                except Exception:
+                    ncc_val = -1
                 if ncc_val > _ncc:
                     _ncc = float(ncc_val)
                     y = int(yval)
@@ -167,8 +182,10 @@ def interpret_translation(image1, image2, yins, xins, ymin, ymax, xmin, xmax, n=
     return _ncc, y, x
 
 
-def calculate_translation(image1, image2, lims):
+def calculate_translation(image1, image2, lims, metric="structural_similarity"):
     PCM = pcm(image1, image2)
     yins, xins, _ = multi_peak_max(PCM)
-    max_peak = interpret_translation(image1, image2, yins, xins, *lims[0], *lims[1])
+    max_peak = interpret_translation(
+        image1, image2, yins, xins, *lims[0], *lims[1], metric=metric
+    )
     return max_peak
